==> NISP-2.2-2-src.zip: nisp/sci_gateway/cpp/sci_polychaos_getgroupinter.cpp <==
//
// Copyright (C) 2008 - INRIA - Michael Baudin
// Copyright (C) 2009 - Digiteo - Michael Baudin
//
// This file must be used under the terms of the GNU Lesser General Public License license :
// http://www.gnu.org/copyleft/lesser.html

extern "C" {
#include "stack-c.h" 
#include "Scierror.h"
#include "localization.h"
#include "gw_nisp.h"
}


/* ==================================================================== */

#include "nisp_gwsupport.hxx" 
#include "nisp_PolynomialChaos_map.hxx" 
#include "nisp_SetRandomVariable_map.hxx" 


/* ==================================================================== */
// 
// polychaos_getgroupinter ( token , ovar )
//   returns the interaction indice of an output variable ovar, where 1<= ovar <= ny.
// polychaos_getgroupinter ( token )
//   returns all interaction indices, as a 1 x (ny) matrix
//
int sci_polychaos_getgroupinter (char *fname)
{
	int nRows, nCols;
	int token;
	double *pdblFinalVar = NULL; //SCILAB return Var
	PolynomialChaos * pc = NULL;
	int ovar;
	double index;
	int ny;
	double * mydata = NULL;

	CheckRhs(1,2) ;
	CheckLhs(0,1) ;
	nisp_gettoken ( fname , 1 , &token );
	if ( Rhs == 2 ) {
		// polychaos_getgroupinter ( token , ovar )
		nisp_GetOneInteger ( fname , 2 , &ovar );
	}
	nisp_token2Polychaos ( fname , 1 , token , &pc );
	if ( Rhs == 1 ) {
		// polychaos_getgroupinter ( token )
		ny = pc-> GetDimensionOutput();
		nRows=1;
		nCols=ny;
		iAllocMatrixOfDouble(Rhs+1, nRows, nCols, &pdblFinalVar);
		pc-> GetGroupIndiceInteraction ( pdblFinalVar );
	} else if ( Rhs == 2 ) {
		// polychaos_getgroupinter ( token , ovar )
		index = pc -> GetGroupIndiceInteraction ( ovar );
		// Returns the result
		nRows=1;
		nCols=1;
		iAllocMatrixOfDouble(Rhs+1, nRows, nCols, &pdblFinalVar);
		pdblFinalVar[0] = index;
	}
	LhsVar(1) = Rhs+1;
	return 0;
}
/* ==================================================================== */

==> NISP-2.4.1-1-src.zip: nisp/sci_gateway/cpp/sci_polychaos_getgroupinter.cpp <==
//
// Copyright (C) 2008 - INRIA - Michael Baudin
// Copyright (C) 2009 - Digiteo - Michael Baudin
//
// This file must be used under the terms of the GNU Lesser General Public License license :
// http://www.gnu.org/copyleft/lesser.html

extern "C" {
#include "stack-c.h" 
#include "Scierror.h"
#include "localization.h"
#include "gw_nisp.h"
}


/* ==================================================================== */

#include "nisp_gwsupport.hxx" 
#include "nisp_PolynomialChaos_map.hxx" 
#include "nisp_SetRandomVariable_map.hxx" 


/* ==================================================================== */
// 
// polychaos_getgroupinter ( token , ovar )
//   returns the interaction indice of an output variable ovar, where 1<= ovar <= ny.
// polychaos_getgroupinter ( token )
//   returns all interaction indices, as a 1 x (ny) matrix
//
int sci_polychaos_getgroupinter (char *fname)
{
	int nRows, nCols;
	int token;
	double *pdblFinalVar = NULL; //SCILAB return Var
	PolynomialChaos * pc = NULL;
	int ovar;
	double index;
	int ny;
	double * mydata = NULL;

	CheckRhs(1,2) ;
	CheckLhs(0,1) ;
	nispgw_gettoken ( fname , 1 , &token );
	if ( Rhs == 2 ) {
		// polychaos_getgroupinter ( token , ovar )
		nispgw_GetOneInteger ( fname , 2 , &ovar );
	}
	nispgw_token2Polychaos ( fname , 1 , token , &pc );
	if ( Rhs == 1 ) {
		// polychaos_getgroupinter ( token )
		ny = pc-> GetDimensionOutput();
		nRows=1;
		nCols=ny;
		iAllocMatrixOfDouble(Rhs+1, nRows, nCols, &pdblFinalVar);
		pc-> GetGroupIndiceInteraction ( pdblFinalVar );
	} else if ( Rhs == 2 ) {
		// polychaos_getgroupinter ( token , ovar )
		index = pc -> GetGroupIndiceInteraction ( ovar );
		// Returns the result
		nRows=1;
		nCols=1;
		iAllocMatrixOfDouble(Rhs+1, nRows, nCols, &pdblFinalVar);
		pdblFinalVar[0] = index;
	}
	LhsVar(1) = Rhs+1;
	return 0;
}
/* ==================================================================== */
